diepvries documentation
=======================

This is the homepage for the documentation of ``diepvries``, a Data Vault
framework written in Python.

By automatically generating SQL statements for a given Data Vault
model, ``diepvries`` is a convenient library to manage data loading
without duplicating many SQL queries.

``diepvries`` is free software, released under the MIT license. You
can check `its source code here
<https://github.com/PicnicSupermarket/diepvries>`_. Bug reports and
contributions are encouraged!

Head over the topics below for more information, or dive directly
:doc:`in the tutorial <tutorial>` if you're eager to write code
already!

Topics
------

.. toctree::

   philosophy
   glossary
   naming-conventions
   security

Get started
-----------

.. toctree::

   installation
   tutorial
   advanced-topics

Developer documentation
-----------------------

.. toctree::

   development
   API documentation <api/modules>
